@@ -32,17 +32,22 @@ TransferHandler::TransferHandler(Transfer * parent, Scheduler * scheduler)
     m_changesFlags(Transfer::Tc_None)
 {
     static int dBusObjIdx = 0;
-    dBusObjIdx++;
-
-    m_dBusObjectPath = "/KGet/Transfers/" + QString::number(dBusObjIdx);
+    m_dBusObjectPath = "/KGet/Transfers/" + QString::number(dBusObjIdx++);
 
     m_kjobAdapter = new KGetKJobAdapter(this, this);
+
+    connect(m_transfer, SIGNAL(capabilitiesChanged()), this, SIGNAL(capabilitiesChanged()));
 }
 
 TransferHandler::~TransferHandler()
 {
 }
 
+Transfer::Capabilities TransferHandler::capabilities() const
+{
+    return m_transfer->capabilities();
+}
+
 void TransferHandler::start()
 {
     if(m_transfer->group()->status() == JobQueue::Running)
@@ -78,11 +83,6 @@ int TransferHandler::remainingTime() const
     return m_transfer->remainingTime();
 }
 
-bool TransferHandler::isResumable() const
-{
-    return m_transfer->isResumable();
-}
-
 KIO::filesize_t TransferHandler::totalSize() const
 {
     return m_transfer->totalSize();
@@ -127,6 +127,8 @@ QVariant TransferHandler::data(int column)
         case 0:
             return dest().fileName();
         case 1:
+            if (status() == Job::Aborted && !error().text.isEmpty())
+                return error().text;
             return statusText();
         case 2:
             if (totalSize() != 0)
@@ -209,7 +211,8 @@ QList<QAction*> TransferHandler::contextActions()
                 << KGet::actionCollection()->action("stop_selected_download");
     }
     actions << KGet::actionCollection()->action("delete_selected_download")
-            << KGet::actionCollection()->action("redownload_selected_download");
+            << KGet::actionCollection()->action("redownload_selected_download")
+            << KGet::actionCollection()->action("select_all");
 
     return actions;
 }
